{% extends "page.html" %}
{% if announcement_logout is string %}
  {% set announcement = announcement_logout %}
{% endif %}

{% block main %}

<div id="logout-main" class="container">
  <p>
    Successfully logged out.
  </p>
</div>

{% endblock %}
