



pip check
IF %ERRORLEVEL% NEQ 0 exit /B 1
python -m jupyterhub --help-all
IF %ERRORLEVEL% NEQ 0 exit /B 1
jupyterhub -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
configurable-http-proxy -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
